@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FilterMAilmangzipTest_H
-#define FilterMAilmangzipTest_H
+#pragma once
 
 #include <QObject>
 
@@ -20,5 +19,3 @@ private Q_SLOTS:
     void canNotImportDataEmptyPath();
     void canNotImportDataUnknowPath();
 };
-
-#endif // FilterMAilmangzipTest_H
