@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,8 +12,8 @@
 #include <Akonadi/ItemCreateJob>
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
-#include <Akonadi/KMime/MessageFlags>
-#include <Akonadi/KMime/MessageParts>
+#include <Akonadi/MessageFlags>
+#include <Akonadi/MessageParts>
 #include <KLocalizedString>
 #include <MailImporter/FilterInfo>
 #include <QFile>
